/*####################################################################
  FILE: shield_test_code_KY-015.ino
  VERSION: 1.0
  Descrizione: Test sensore MPL3115A2 con stampa dati su OLED

  Ultima modifica il 18/01/2020
  Applicazione modificata da Adriano Gandolfo
  Sito web https://www.adrirobot.it
  Blog https://it.emcelettronica.com/author/adrirobot
  Pagina Facebook https://www.facebook.com/Adrirobot-318949048122955
  Istagram https://www.instagram.com/adrirobot/
  This example code is in the public domain.
  #################################################################### */

// Definizione dei pin di collegamento
#define sclk 13
#define mosi 11
#define cs   10
#define rst  9
#define dc   8

// Impostazione display OLED
#include <Adafruit_GFX.h>
#include <Adafruit_SSD1331.h>
#include <SPI.h>
Adafruit_SSD1331 display = Adafruit_SSD1331(cs, dc, rst);

// Impostazione sensore MPL3115A2
#include <Wire.h>
#include "SparkFunMPL3115A2.h"
MPL3115A2 myPressure; //Create an instance of the object

// Definizione dei colori
#define BLACK           0x0000
#define BLUE            0x001F
#define RED             0xF800
#define GREEN           0x07E0
#define CYAN            0x07FF
#define MAGENTA         0xF81F
#define YELLOW          0xFFE0
#define WHITE           0xFFFF

void setup()   {
  Serial.begin(9600);
  display.begin();
  Serial.println("Test sensore MPL3115A2");

  Wire.begin();       // Attiva i2c bus
  myPressure.begin(); // Attiva il sensore

  //Configurazione sensore
  myPressure.setModeAltimeter(); // Measure altitude above sea level in meters
  myPressure.setOversampleRate(7); // Set Oversample to the recommended 128
  myPressure.enableEventFlags(); // Enable all three pressure and temp event flags

  // Messaggio iniziale
  display.fillScreen(BLACK);
  display.setTextSize(1);
  display.setTextColor(BLUE);
  display.setRotation(2); //Ruota display
  display.setCursor(0, 0);
  display.println("www.adrirobot.it");
  display.println("");
  display.setTextColor(GREEN);
  display.println("Multitest shield");
  display.println("");
  display.println(" TEST SENSORE");
  display.println("");
  display.println("    MPL3115A2");
  delay(3000);
}

void loop()
{
  // Uscita su monitor seriale
  float altitude = myPressure.readAltitude();
  Serial.print("Altitudine(m):");
  Serial.print(altitude, 2);

  float pressure = myPressure.readPressure();
  Serial.print(" Pressione(Pa):");
  Serial.print(pressure, 2);

  float temperature = myPressure.readTemp();
  Serial.print(" Temp(C):");
  Serial.print(temperature, 2);
  Serial.println();

  // Uscita su display OLED
  display.fillScreen(BLACK);
  display.setCursor(0, 0);
  display.setTextSize(1);
  display.setTextColor(MAGENTA);
  display.println("VALORI MISURATI");
  display.println("");

  display.setTextColor(WHITE);
  display.print("Altit.(m):");
  display.setTextColor(RED);
  display.println(altitude, 1);

  display.println("");
  display.setTextColor(WHITE);
  display.print("Pres.(Pa):");
  display.setTextColor(GREEN);
  display.println(pressure, 1);

  display.println("");
  display.setTextColor(WHITE);
  display.print("Temp. (C):");
  display.setTextColor(YELLOW);
  display.println(temperature, 1);

  delay (1000); // Pausa di 1 secondo
}

